<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:output 
        encoding="UTF-8" 
        method="html"
        doctype-system="http://www.w3.org/TR/html4/strict.dtd" 
        doctype-public="-//W3C//DTD HTML 4.01//EN" />

    <xsl:template match="meta" mode="header">
        <FORM ACTION="saveheader" METHOD="get">
            <FIELDSET>
                <LEGEND>Test informations:</LEGEND>
                <TABLE>
                    <TR>
                        <TD><LABEL FOR="date">Date: </LABEL>
                        <INPUT TYPE="text" ID="date" NAME="date" SIZE="10">
                            <xsl:attribute name="value">
                                <xsl:value-of select="./date"/>
                            </xsl:attribute>
                        </INPUT>
                        </TD>
                        <TD>Test plan version: <xsl:value-of select="./test-version"/></TD>
                    </TR>
                    <TR>
                        <TD><LABEL FOR="test-system">Operating System: </LABEL>
                            <INPUT TYPE="text" ID="test-system" NAME="test-system" SIZE="15">
                                <xsl:attribute name="value">
                                    <xsl:value-of select="./test-system"/>
                                </xsl:attribute>
                            </INPUT>
                        </TD>
                        <TD><xsl:value-of select="./product-name"/> version: <xsl:value-of select="./product-version"/></TD>
                    </TR>
                    <TR>
                        <TD><LABEL FOR="tester">Tester: </LABEL>
                            <INPUT TYPE="text" ID="tester" NAME="tester" SIZE="35">
                                <xsl:attribute name="value">
                                    <xsl:value-of select="./tester"/>
                                </xsl:attribute>
                            </INPUT>
                        </TD>
                        <TD><LABEL FOR="test-duration">Test duration: </LABEL>
                            <INPUT TYPE="text" ID="test-duration" NAME="test-duration" SIZE="6">
                                <xsl:attribute name="value">
                                    <xsl:value-of select="./test-duration"/>
                                </xsl:attribute>
                            </INPUT>
                        </TD>
                    </TR>
                    <TR>
                        <TD COLSPAN="2">
                            <LABEL FOR="comment">Comment:</LABEL>
                            <BR/>
                            <TEXTAREA ID="comment" NAME="comment" COLS="80" ROWS="4">
                                <xsl:value-of select="./comment"/>
                            </TEXTAREA>
                        </TD>
                    </TR>
                </TABLE>
                <INPUT TYPE="submit" VALUE="Store informations"/>
                <INPUT TYPE="reset" VALUE="Reset"/>
            </FIELDSET>
        </FORM>
    </xsl:template>

    <xsl:template match="testsuite" mode="testsuites">
        <TR>
            <TD>
                <A>
                    <xsl:attribute name="HREF">
                        <xsl:text>select-testsuite?suite=</xsl:text>
                        <xsl:value-of select="@id"/>
                    </xsl:attribute>
                    <xsl:value-of select="@description"/>
                </A>
            </TD>
            <xsl:variable name="all" select="count(.//result)"/>
            <xsl:variable name="passed" select="count(.//result[@value = 'passed'])"/>
            <xsl:variable name="failed" select="count(.//result[@value = 'failed'])"/>
            <TD ALIGN="RIGHT">
                <xsl:if test="$passed > 0">
                    <xsl:attribute name="BGCOLOR">GREEN</xsl:attribute>
                </xsl:if>
                <xsl:value-of select="$passed"/>
            </TD>
            <TD ALIGN="RIGHT">
                <xsl:if test="$failed > 0">
                    <xsl:attribute name="BGCOLOR">RED</xsl:attribute>
                </xsl:if>
                <xsl:value-of select="$failed"/>
            </TD>
            <TD ALIGN="RIGHT">
                <xsl:value-of select="$all - $passed - $failed"/>
            </TD>
            <TD ALIGN="RIGHT">
                <xsl:value-of select="$all"/>
            </TD>
        </TR>
    </xsl:template>

    <xsl:template match="testplan">
        <HTML>
            <HEAD>
                <!--
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
                -->
                <TITLE>Test plan for <xsl:value-of select="./meta/product-name"/></TITLE>
            </HEAD>
            <BODY>
                <CENTER><H2>Test plan for <xsl:value-of select="./meta/product-name"/></H2></CENTER>
                Actions: [<A HREF="quit">Quit</A>]
                <xsl:apply-templates mode="header"/>
                Test suites:
                <TABLE BORDER="1" CELLSPACING="0">
                    <TR>
                        <TH>Test suite</TH>
                        <TH>Passed</TH>
                        <TH>Failed</TH>
                        <TH>N/A</TH>
                        <TH>Total</TH>
                    </TR>
                    <xsl:apply-templates mode="testsuites"/>
                    <TR>
                        <xsl:variable name="passed" select="count(.//result[@value = 'passed'])"/>
                        <xsl:variable name="failed" select="count(.//result[@value = 'failed'])"/>
                        <xsl:variable name="all"    select="count(.//result)"/>
                        <TD>
                            <B>Sum:</B>
                        </TD>
                        <TD ALIGN="RIGHT">
                            <B><xsl:value-of select="$passed"/></B>
                        </TD>
                        <TD ALIGN="RIGHT">
                            <B><xsl:value-of select="$failed"/></B>
                        </TD>
                        <TD ALIGN="RIGHT">
                            <B><xsl:value-of select="$all - $passed - $failed"/></B>
                        </TD>
                        <TD ALIGN="RIGHT">
                            <B><xsl:value-of select="$all"/></B>
                        </TD>
                    </TR>
                </TABLE>
            </BODY>
        </HTML>
    </xsl:template>

    <xsl:template match="text()"/>
    <xsl:template match="text()" mode="header"/>
    <xsl:template match="text()" mode="testsuites"/>

</xsl:stylesheet>
