<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:output encoding="ISO-8859-1" method="text"/>

    <xsl:template match="result" mode="test">
        <xsl:text>\item \test[0]{</xsl:text>
        <xsl:value-of select="."/>
        <xsl:text>}&#10;</xsl:text>
    </xsl:template>

    <xsl:template match="script" mode="test">
        <xsl:text>\item </xsl:text>
        <xsl:value-of select="@description"/>
        <xsl:text> (</xsl:text>
        <xsl:value-of select="@language"/>
        <xsl:text> script)&#10;</xsl:text>
    </xsl:template>

    <xsl:template match="step" mode="test">
        <xsl:text>\item </xsl:text>
        <xsl:value-of select="."/>
        <xsl:text>&#10;</xsl:text>
    </xsl:template>

    <xsl:template match="test" mode="tests">
        <xsl:text>\item \textbf{</xsl:text>
        <xsl:value-of select="@description"/>
        <xsl:text>}&#10;</xsl:text>
        <xsl:text>\smallsec{Precondition:}&#10;</xsl:text>
        <xsl:value-of select="precondition"/>

        <xsl:text>\smallsec{Steps:}&#10;</xsl:text>
        <xsl:text>\begin{enumerate}[(1)]&#10;</xsl:text>
        <xsl:apply-templates mode="test" select="steps"/>
        <xsl:text>\end{enumerate}&#10;</xsl:text>

        <xsl:text>\smallsec{Expected Results:}&#10;</xsl:text>
        <xsl:text>\begin{compactenum}&#10;</xsl:text>
        <xsl:apply-templates mode="test" select="results"/>
        <xsl:text>\end{compactenum}&#10;</xsl:text>
    </xsl:template>

    <xsl:template match="general-precondition" mode="testsuites">
        <![CDATA[\minisec{General Precondition:}]]>
        <xsl:value-of select="."/>
        <xsl:text>\\&#10;</xsl:text>
    </xsl:template>

    <xsl:template match="testsuite" mode="testsuites">
        <xsl:text>\testsection{</xsl:text>
        <xsl:value-of select="@description"/>
        <xsl:text>}&#10;</xsl:text>
        <xsl:apply-templates mode="testsuites"/>
        <xsl:text>\begin{enumerate}&#10;</xsl:text>
        <xsl:apply-templates mode="tests"/>
        <xsl:text>\end{enumerate}&#10;&#10;</xsl:text>
    </xsl:template>

    <xsl:template match="testsuite" mode="overview">
        <xsl:text>\test[0]{Test suite </xsl:text>
        <xsl:value-of select="count(preceding-sibling::*[name() = 'testsuite']) + 1"/>
        <xsl:text>: </xsl:text><xsl:value-of select="@description"/><xsl:text>}\\&#10;</xsl:text>
    </xsl:template>

    <xsl:template match="meta">
<xsl:text>\section*{\Huge{Test plan for </xsl:text>
<xsl:value-of select="./product-name"/><xsl:text>}\\\vspace{0.5cm}}</xsl:text>
<![CDATA[
% test plan header
\T\begin{tabular*}{0.85\textwidth}{@{\extracolsep{\fill}}*{3}l}
\W\begin{tabular}{ll}
    Date: ]]><xsl:value-of select="test-date"/>
<![CDATA[ & Test plan version: \version\\[1.5ex]
    Operating System: ]]><xsl:value-of select="test-system"/>
<![CDATA[ & ]]><xsl:value-of select="product-name"/>
<![CDATA[ version: ]]><xsl:value-of select="product-version"/><![CDATA[\\[1.5ex]
    Tester: ]]><xsl:value-of select="tester"/><![CDATA[ & Test duration: ]]>
<xsl:value-of select="test-duration"/><![CDATA[ \\[1.5ex]
    Comment: & ]]><xsl:value-of select="comment"/><![CDATA[ \\[5ex]
    \W\end{tabular}
\T\end{tabular*}

This test plan should be used to verify that all functions of ]]><xsl:value-of select="product-name"/>
<![CDATA[ work as expected.
Every test suite can execute separatly. It is not necessary to
execute all tests suites consecutively.

Please state in your problem report the version number of this document (\version) and the
number of the test cases which fail.
\T\section*{Overview}
\W\large\textbf{Overview}\small

Test suite completely successful?\\
]]>
        <xsl:apply-templates mode="overview" select="/"/>
<![CDATA[
\clearpage

%------------------------------------------------------
%
\small 
]]>
        <xsl:apply-templates mode="testsuites" select="/"/>

    </xsl:template>

    <xsl:template match="testplan">
<![CDATA[
\documentclass[a4paper,
               11pt,
               halfparskip,
               headsepline,
               final,
               titlepage]{scrartcl}

% hyperlatex
\usepackage{hyperlatex}

% font table with 256 chars
\usepackage[T1]{fontenc}
\usepackage{mathptmx}
\usepackage[ansinew]{inputenc}
\usepackage{marvosym}

% graphicx
\usepackage[dvips]{graphicx}

\T\frenchspacing

% special packages for testitems
\usepackage{amssymb}
\usepackage{amsfonts}
\usepackage{ifthen}
\usepackage{enumerate}
\usepackage{paralist}
% custom commands:

% EDIT HERE: Test plan version!
]]>

<xsl:text>\newcommand{\version}{</xsl:text><xsl:value-of select="./meta/test-version"/><xsl:text>}</xsl:text>
<![CDATA[
% version date (last change)
]]>
<xsl:text>\newcommand{\versiondate}{</xsl:text><xsl:value-of select="./meta/test-date"/><xsl:text>}</xsl:text>

<![CDATA[
\W\newcommand{\dotfill}{..............}
\W\newcommand{\test}[2][0]{#2 \dotfill \html{nbsp} \code{O} ja \html{nbsp}\html{nbsp} \code{O} nein \html{br}}
    
\texonly{
\newcommand{\test}[2][0]{
	#2 \dotfill
	$\ifthenelse{\equal{#1}{1}}{\blacksquare}{\square}_{yes}\hspace{5pt} %\boxtimes
	\ifthenelse{\equal{#1}{2}}{\blacksquare}{\square}_{no}$\\}
    }

\renewcommand{\labelenumi}{\thesection.\theenumi}
\newcommand{\testsection}[2]{\section*{\addtocounter{section}{1}Test suite \thesection: #1}}
\newcommand{\guiitem}[1]{{\sl\sffamily #1}}

% compact minisec
\newcommand{\smallsec}[1]{%
\vspace{-5pt}\minisec{\small{#1}}\vspace{-7pt}
}

% parameters for paralists
%\setlength{\plpartopsep}{16pt}
%\setlength{\plparsep}{6pt}


% page style
\usepackage{fancyhdr}
\pagestyle{fancy}
\T\fancyhead{} % clear all fields
\T\fancyhead[LO,RE]{Test plan for ]]><xsl:value-of select="meta/product-name"/><![CDATA[ \scriptsize{(v\version)}}
\T\fancyhead[RO,LE]{\thepage}

% for hyperlinks
\usepackage[dvips]{hyperref}

%%% BEGIN document %%%%

\begin{document}
\thispagestyle{empty}
]]>
        <xsl:apply-templates/>
<![CDATA[
\clearpage

\end{document}
]]>
    </xsl:template>

    <xsl:template match="text()" mode="test"/>
    <xsl:template match="text()" mode="tests"/>
    <xsl:template match="text()" mode="testsuites"/>
    <xsl:template match="text()" mode="overview"/>
    <xsl:template match="text()"/>

</xsl:stylesheet>
